==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-kogito-runtimes/springboot/addons/persistence/postgresql/src/main/java/org/kie/kogito/persistence/springboot/PostgresqlProcessInstancesFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.persistence.springboot;

import org.kie.kogito.persistence.postgresql.AbstractProcessInstancesFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import io.vertx.pgclient.PgPool;

@Component
public class PostgresqlProcessInstancesFactory extends AbstractProcessInstancesFactory {

    @Autowired
    public PostgresqlProcessInstancesFactory(@Qualifier("kogito") PgPool client,
            @Value("${kogito.persistence.query.timeout.millis:10000}") Long queryTimeout,
            @Value("${kogito.persistence.optimistic.lock:false}") Boolean lock) {
        super(client, queryTimeout, lock);
    }

    protected PostgresqlProcessInstancesFactory() {
        super();
    }

}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-kogito-runtimes/springboot/addons/persistence/postgresql/src/main/java/org/kie/kogito/persistence/springboot/PostgresqlProcessInstancesFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.persistence.springboot;

import java.util.List;

import org.kie.kogito.internal.process.runtime.HeadersPersistentConfig;
import org.kie.kogito.persistence.postgresql.AbstractProcessInstancesFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import io.vertx.pgclient.PgPool;

@Component
public class PostgresqlProcessInstancesFactory extends AbstractProcessInstancesFactory {

    @Autowired
    public PostgresqlProcessInstancesFactory(@Qualifier("kogito") PgPool client,
            @Value("${kogito.persistence.query.timeout.millis:10000}") Long queryTimeout,
            @Value("${kogito.persistence.optimistic.lock:false}") Boolean lock,
            @Value("${kogito.persistence.headers.enabled:false}") Boolean headersEnabled,
            @Value("${kogito.persistence.headers.excluded:}") List<String> headersExcluded) {
        super(client, queryTimeout, lock, new HeadersPersistentConfig(headersEnabled, headersExcluded));
    }

    protected PostgresqlProcessInstancesFactory() {
        super();
    }

}
